@@ -36,7 +36,7 @@ def unescape_data(data):
     """Unescape the data
     """
     data = [ x.replace("\\r", "\r").replace("\\n", "\n")
-              for x in data.split('\\\\') ]
+             for x in data.split('\\\\') ]
     return '\\'.join(data)
 
 
@@ -59,7 +59,7 @@ def unfold_lines(data):
     line = ''
     while i < len(lines):
         next = lines[i]
-        if next.startswith(' ') or next.startswith('\t'):
+        if next and (next[0] == ' ' or next[0] == '\t'):
             line += next[1:]
         else:
             if line:
@@ -103,23 +103,24 @@ def read_name(line):
         name
         [parameters]value
     """
-    c, lexeme = line[0], ''
     # Test first character of name
+    c = line[0]
     if not c.isalnum() and c != '-':
         raise SyntaxError, 'unexpected character (%s)' % c
-    # Test if line contains ':'
-    if not ':' in line:
-        raise SyntaxError, 'character (:) must appear at least one time'
-    # Cut name
-    while not c in (';', ':'):
-        line = line[1:]
-        if c.isalnum() or c in ['-', '_']:
-            lexeme += c
-        else:
-            raise SyntaxError, "unexpected character '%s' (%s)" % (c, ord(c))
-        c = line[0]
 
-    return lexeme, line
+    # Test the rest
+    idx = 1
+    n = len(line)
+    while idx < n:
+        c = line[idx]
+        if c in (';', ':'):
+            return line[:idx], line[idx:]
+        if c.isalnum() or c in ('-', '_'):
+            idx += 1
+            continue
+        raise SyntaxError, "unexpected character '%s' (%s)" % (c, ord(c))
+
+    raise SyntaxError, 'unexpected end of line (%s)' % line
 
 
 # Manage an icalendar content line value property [with parameters] :
@@ -138,13 +139,13 @@ def read_name(line):
 #     7 --> value to begin (just after ':')
 #     8 --> value begun
 
-# Tokens
-TPARAM, TVALUE = 0, 1
-token_name = ['name', 'parameter', 'value']
-
+error1 = 'unexpected character (%s) at status %s'
+error2 = 'unexpected repeated character (%s) at status %s'
 
 def get_tokens(property):
-    status, lexeme, last = 0, '', ''
+    parameters = {}
+    value = ''
+    status, last = 0, ''
 
     # Init status
     c, property = property[0], property[1:]
@@ -153,23 +154,24 @@ def get_tokens(property):
     elif c == ':':
         status = 7
 
-    error1 = 'unexpected character (%s) at status %s'
-    error2 = 'unexpected repeated character (%s) at status %s'
-
     for c in property:
+        # value begun
+        if status == 8:
+            value += c
+
         # parameter begun (just after ';')
-        if status == 1:
+        elif status == 1:
             if c.isalnum() or c in ('-'):
-                lexeme, status = c, 2
+                param_name, status = c, 2
             else:
                 raise SyntaxError, error1 % (c, status)
 
         # param-name begun
         elif status == 2:
             if c.isalnum() or c in ('-'):
-                lexeme += c
+                param_name += c
             elif c == '=':
-                lexeme += c
+                parameters[param_name] = []
                 status = 3
             else:
                 raise SyntaxError, error1 % (c, status)
@@ -177,61 +179,63 @@ def get_tokens(property):
         # param-name ended, param-value beginning
         elif status == 3:
             if c == '"':
-                lexeme += c
+                param_value = c
                 status = 4
             elif c in (';', ':', ',') :
                 raise SyntaxError, error1 % (c, status)
             else:
-                lexeme += c
+                param_value = c
                 status = 5
 
         # param-value quoted begun (just after '"')
         elif status == 4:
             if c == '"':
-                lexeme += c
-                status = 6
-            else:
-                lexeme += c
-
-        # param-value NOT quoted begun
-        elif status == 5:
-            if c in (':', ';', ',') :
-                status = 6
-            elif c=='"':
-                raise SyntaxError, error1 % (c, status)
-            else:
-                lexeme += c
-
-        # value to begin (just after ':')
-        elif status == 7:
-            lexeme, status = c, 8
-
-        # value begun
-        elif status == 8:
-            lexeme += c
-
-        # param-value ended (just after '"' for quoted ones)
-        if status == 6:
-            if c == ':':
-                status = 7
-                yield TPARAM, lexeme
-            elif c == ';':
-                status = 1
-                yield TPARAM, lexeme
-            elif c == ',':
-                lexeme += c
-                status = 3
-            elif c == '"':
                 if last == '"':
                     raise SyntaxError, error2 % (c, status)
                 last = '"'
+                param_value += c
+                status = 6
+            else:
+                param_value += c
+
+        # param-value NOT quoted begun
+        elif status == 5:
+            if c == ':':
+                parameters[param_name].append(param_value)
+                status = 7
+            elif c == ';':
+                parameters[param_name].append(param_value)
+                status = 1
+            elif c == ',':
+                parameters[param_name].append(param_value)
+                status = 3
+            elif c == '"':
+                raise SyntaxError, error1 % (c, status)
+            else:
+                param_value += c
+
+        # value to begin (just after ':')
+        elif status == 7:
+            value, status = c, 8
+
+        # param-value ended (just after '"' for quoted ones)
+        elif status == 6:
+            parameters[param_name].append(param_value)
+            if c == ':':
+                status = 7
+            elif c == ';':
+                status = 1
+            elif c == ',':
+                status = 3
             else:
                 raise SyntaxError, error1 % (c, status)
 
     if status not in (7, 8):
         raise SyntaxError, 'unexpected property (%s)' % property
 
-    yield TVALUE, lexeme
+    # Unescape special characters (TODO Check the spec)
+    value = unescape_data(value)
+    return value, parameters
 
 
 
@@ -251,16 +255,7 @@ def parse_table(data):
         parameters = {}
         name, line = read_name(line)
         # Read the parameters and the property value
-        for token, lexeme in get_tokens(line):
-            if token == TPARAM:
-                param_name, param_value = lexeme.split('=')
-                parameters[param_name] = param_value.split(',')
-            elif token == TVALUE:
-                # Unescape special characters
-                # TODO Check the spec
-                value = unescape_data(lexeme)
-            else:
-                raise SyntaxError, 'unexpected %s' % token_name[token]
+        value, parameters = get_tokens(line)
         yield name, value, parameters
 
 
