@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright (C) 2005-2007 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2005-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,4 +39,4 @@ class Message(File):
 
     def get_header(self, name):
         name = name.lower()
-        return self.headers[name]
+        return self.headers.get(name)
