@@ -21,6 +21,7 @@
 
 # Import from the Standard Library
 from cStringIO import StringIO
+from os import close as close_fd
 from types import FileType
 import copy
 import socket
@@ -261,6 +262,8 @@ class Context(object):
         self.pagetotal = XMLContent.encode('#pagetotal/>')
         self.multibuild = False
         self.doc_attr = {'pagesize': A4} # FIXME Should be customizable
+        # Image cache
+        self.check_img_cache = {}
 
 
     def init_base_style_sheet(self):
@@ -300,6 +303,8 @@ class Context(object):
 
     def get_tmp_file(self):
         fd, filename = tempfile.mkstemp(dir=self.tmp_dir)
+        # close fd
+        close_fd(fd)
         return vfs.open(filename, 'w')
 
 
@@ -1132,7 +1137,7 @@ def create_img(attributes, context, check_dimension=False):
 def build_image(filename, width, height, context):
     # determines behavior of both arguments(width, height)
     kind = 'direct'
-    file_path, size = check_image(filename, context)
+    file_path, size = context.check_image(filename)
     x, y = size
     #FIXME not like html
     if height or width:
@@ -1430,7 +1435,7 @@ def build_img_attributes(attributes, context):
     for key, attr_value in attributes.iteritems():
         key = key[1]
         if key == 'src':
-            file_path, size = check_image(attr_value, context)
+            file_path, size = context.check_image(attr_value)
             attrs[(None, 'src')] = file_path
         elif key == 'width':
             attrs[(None, 'width')] = format_size(attr_value)
