@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright (C) 2005-2007 Juan David Ibáñez Palomar <jdavid@itaapy.com>
-# Copyright (C) 2005-2007 Nicolas Deram <nicolas@itaapy.com>
+# Copyright (C) 2005-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2006-2007 Nicolas Deram <nicolas@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ from datetime import datetime
 # Import from itools
 from itools.csv import Property
 from itools.datatypes import URI
-from itools.ical import icalendar, icalendarTable
+from itools.ical import iCalendar, icalendarTable
 
 
 # Example with 1 event
@@ -88,18 +88,13 @@ END:VCALENDAR
 class icalTestCase(unittest.TestCase):
 
     def setUp(self):
-        src = icalendar()
-        src.load_state_from_string(content)
-        self.cal1 = src
-
-        src = icalendar()
-        src.load_state_from_string(content2)
-        self.cal2 = src
+        self.cal1 = iCalendar(string=content)
+        self.cal2 = iCalendar(string=content2)
 
 
     def test_new(self):
         """Test new"""
-        cal = icalendar()
+        cal = iCalendar()
 
         properties = []
         for name in cal.properties:
@@ -120,24 +115,23 @@ class icalTestCase(unittest.TestCase):
 
 
     def test_property(self):
-        """
-        Test to create, access and encode a property with or without
+        """Test to create, access and encode a property with or without
         parameters.
         """
         # Property without parameter
         expected = ['SUMMARY:This is the summary\n']
 
         property_value = Property('This is the summary')
-        output = icalendar.encode_property('SUMMARY', property_value)
+        output = self.cal1.encode_property('SUMMARY', property_value)
         self.assertEqual(output, expected)
 
         # Property with one parameter
         expected = ['ATTENDEE;MEMBER="mailto:DEV-GROUP@host.com":'
                     'mailto:darwin@itaapy.com\n']
 
-        params = {'MEMBER': ['"mailto:DEV-GROUP@host.com"']}
-        value = Property('mailto:darwin@itaapy.com', params)
-        output = icalendar.encode_property('ATTENDEE', value)
+        member = '"mailto:DEV-GROUP@host.com"'
+        value = Property('mailto:darwin@itaapy.com', MEMBER=[member])
+        output = self.cal1.encode_property('ATTENDEE', value)
         self.assertEqual(output, expected)
 
 
@@ -166,8 +160,8 @@ class icalTestCase(unittest.TestCase):
         properties['MYADD'] = Property(u'Résumé à crêtes')
         value = Property(u'Property added by calling add_property')
         properties['DESCRIPTION'] = value
-        param = '"mailto:DEV-GROUP@host2.com"'
-        value = Property('mailto:darwin@itaapy.com', {'MEMBER': [param]})
+        member = '"mailto:DEV-GROUP@host2.com"'
+        value = Property('mailto:darwin@itaapy.com', MEMBER=[member])
         properties['ATTENDEE'] = value
         uid = cal.add_component('VEVENT', **properties)
 
@@ -183,7 +177,7 @@ class icalTestCase(unittest.TestCase):
         """
         Test to add property and component to an empty icalendar object.
         """
-        cal = icalendar()
+        cal = iCalendar()
         cal.add_component('VEVENT')
         self.assertEqual(len(cal.get_components('VEVENT')), 1)
 
@@ -231,7 +225,7 @@ class icalTestCase(unittest.TestCase):
         event = cal.get_components('VEVENT')[0]
         version = event.get_version()
         for prop_name in version:
-            datatype = cal.get_datatype(prop_name)
+            datatype = cal.get_record_datatype(prop_name)
             if datatype.multiple is False:
                 prop = version[prop_name]
                 property = self.property_to_string(prop_name, prop)
@@ -299,7 +293,7 @@ class icalTestCase(unittest.TestCase):
             for prop_name in version:
                 if prop_name == 'DTSTAMP':
                     continue
-                datatype = cal.get_datatype(prop_name)
+                datatype = cal.get_record_datatype(prop_name)
                 if datatype.multiple is False:
                     prop = version[prop_name]
                     property = self.property_to_string(prop_name, prop)
@@ -379,13 +373,13 @@ class icalTestCase(unittest.TestCase):
         # property ATTENDEE
         name = 'ATTENDEE'
         value = event.get_property_values(name)
-        param = ['"mailto:DEV-GROUP@host2.com"']
-        value.append(Property('mailto:darwin@itaapy.com', {'MEMBER': param}))
+        member = '"mailto:DEV-GROUP@host2.com"'
+        value.append(Property('mailto:darwin@itaapy.com', MEMBER=[member]))
         cal.update_component(event.uid, **{name: value})
 
         property = event.get_property_values(name)
         self.assertEqual(str(property[0].value), 'mailto:jdoe@itaapy.com')
-        self.assertEqual(property[1].parameters, {'MEMBER': param})
+        self.assertEqual(property[1].parameters, {'MEMBER': [member]})
         self.assertEqual(property[1], value[1])
 
 
@@ -410,14 +404,13 @@ class icalTestCase(unittest.TestCase):
         cal.update_component(event.uid, **{name: value})
         self.assertEqual(event.get_property_values(name), value)
 
-        name, value = 'ATTENDEE', []
-        param = ['"mailto:DEV-GROUP@host2.com"']
-        value.append(Property(URI.decode('mailto:darwin@itaapy.com'),
-                              {'MEMBER': param}))
-        value.append(Property(URI.decode('mailto:jdoe@itaapy.com')))
-        value.append(Property(URI.decode('mailto:jsmith@itaapy.com')))
-        cal.update_component(event.uid, **{name: value})
-        self.assertEqual(event.get_property_values(name), value)
+        member = '"mailto:DEV-GROUP@host2.com"'
+        value = [
+            Property(URI.decode('mailto:darwin@itaapy.com'), MEMBER=[member]),
+            Property(URI.decode('mailto:jdoe@itaapy.com')),
+            Property(URI.decode('mailto:jsmith@itaapy.com'))]
+        cal.update_component(event.uid, ATTENDEE=value)
+        self.assertEqual(event.get_property_values('ATTENDEE'), value)
 
 
     def test_search_events(self):
@@ -585,21 +578,20 @@ class icalTestCase(unittest.TestCase):
         self.assertEqual(conflicts, [(uid1, uid2)])
 
 
+
 class icalTableTestCase(unittest.TestCase):
 
     def setUp(self):
-        src = icalendar()
-        src.load_state_from_string(content)
+        src = iCalendar(string=content)
         src = StringIO(src.to_str())
         cal = icalendarTable()
-        cal._load_state_from_ical_file(src)
+        cal.load_state_from_ical_file(src)
         self.cal1 = cal
 
-        src = icalendar()
-        src.load_state_from_string(content2)
+        src = iCalendar(string=content2)
         src = StringIO(src.to_str())
         cal = icalendarTable()
-        cal._load_state_from_ical_file(src)
+        cal.load_state_from_ical_file(src)
         self.cal2 = cal
 
 
@@ -607,54 +599,35 @@ class icalTableTestCase(unittest.TestCase):
         """Test new"""
         cal = icalendarTable()
 
-        properties = []
-        for name in cal.properties:
-            params = cal.properties[name].parameters
-            value = cal.properties[name].value
-            property = '%s;%s:%s' % (name, params, value)
-            properties.append(property)
-
-        # Test properties
-        expected_properties = [
-            u'VERSION;{}:2.0',
-            u'PRODID;{}:-//itaapy.com/NONSGML ikaaro icalendar V1.0//EN']
-        self.assertEqual(properties, expected_properties)
-
         # Test components
         self.assertEqual(len(cal.get_components()), 0)
         self.assertEqual(cal.get_components('VEVENT'), [])
 
 
     def test_property(self):
-        """
-        Test to create, access and encode a property with or without
+        """Test to create, access and encode a property with or without
         parameters.
         """
         # Property without parameter
         expected = ['SUMMARY:This is the summary\n']
 
         property_value = Property('This is the summary')
-        output = icalendar.encode_property('SUMMARY', property_value)
+        output = self.cal1.encode_property('SUMMARY', property_value)
         self.assertEqual(output, expected)
 
         # Property with one parameter
         expected = ['ATTENDEE;MEMBER="mailto:DEV-GROUP@host.com":'
                     'mailto:darwin@itaapy.com\n']
 
-        params = {'MEMBER': ['"mailto:DEV-GROUP@host.com"']}
-        value = Property('mailto:darwin@itaapy.com', params)
-        output = icalendar.encode_property('ATTENDEE', value)
+        member = '"mailto:DEV-GROUP@host.com"'
+        value = Property('mailto:darwin@itaapy.com', MEMBER=[member])
+        output = self.cal1.encode_property('ATTENDEE', value)
         self.assertEqual(output, expected)
 
 
     def test_get_property(self):
         cal = self.cal1
 
-        # icalendar property
-        expected = '2.0'
-        property = cal.get_property('VERSION')
-        self.assertEqual(property.value, expected)
-
         # Component property
         events = cal.get_components('VEVENT')
         properties = events[0][-1]
@@ -672,8 +645,8 @@ class icalTableTestCase(unittest.TestCase):
         properties['MYADD'] = Property(u'Résumé à crêtes')
         value = Property(u'Property added by calling add_property')
         properties['DESCRIPTION'] = value
-        param = '"mailto:DEV-GROUP@host2.com"'
-        value = Property('mailto:darwin@itaapy.com', {'MEMBER': [param]})
+        member = '"mailto:DEV-GROUP@host2.com"'
+        value = Property('mailto:darwin@itaapy.com', MEMBER=[member])
         properties['ATTENDEE'] = value
         properties['type'] = 'VEVENT'
         uid = cal.add_record(properties).UID
@@ -694,10 +667,6 @@ class icalTableTestCase(unittest.TestCase):
         cal.add_record({'type': 'VEVENT'})
         self.assertEqual(len(cal.get_components('VEVENT')), 1)
 
-        value = Property('PUBLISH')
-        cal.set_property('METHOD', value)
-        self.assertEqual(cal.get_property('METHOD'), value)
-
 
     def property_to_string(self, prop_name, prop):
         """
@@ -715,24 +684,6 @@ class icalTableTestCase(unittest.TestCase):
         """Test loading a simple calendar."""
         cal = self.cal1
 
-        # Test icalendar properties
-        properties = []
-        for name in cal.properties:
-            property_value = cal.properties[name]
-            # Only property METHOD can occur several times, we give only one
-            if isinstance(property_value, list):
-                property_value = property_value[0]
-            params = property_value.parameters
-            value = property_value.value
-            property = '%s;%s:%s' % (name, params, value)
-            properties.append(property)
-
-        expected_properties = [
-            u'VERSION;{}:2.0',
-            u'METHOD;{}:PUBLISH',
-            u'PRODID;{}:-//Mozilla.org/NONSGML Mozilla Calendar V1.0//EN' ]
-        self.assertEqual(properties, expected_properties)
-
         # Test component properties
         properties = []
         event = cal.get_components('VEVENT')[0]
@@ -740,7 +691,7 @@ class icalTableTestCase(unittest.TestCase):
         for prop_name in version:
             if prop_name in ('ts', 'id', 'type', 'UID', 'SEQUENCE'):
                 continue
-            datatype = cal.get_datatype(prop_name)
+            datatype = cal.get_record_datatype(prop_name)
             if getattr(datatype, 'multiple', False) is False:
                 prop = version[prop_name]
                 property = self.property_to_string(prop_name, prop)
@@ -786,20 +737,6 @@ class icalTableTestCase(unittest.TestCase):
         """Test loading a 2 events calendar."""
         cal = self.cal2
 
-        properties = []
-        for name in cal.properties:
-            params = cal.properties[name].parameters
-            value = cal.properties[name].value
-            property = '%s;%s:%s' % (name, params, value)
-            properties.append(property)
-
-        # Test properties
-        expected_properties = [
-            u'VERSION;{}:2.0',
-            u'METHOD;{}:PUBLISH',
-            u'PRODID;{}:-//Mozilla.org/NONSGML Mozilla Calendar V1.0//EN' ]
-        self.assertEqual(properties, expected_properties)
-
         events = []
         for event in cal.get_components('VEVENT'):
             version = event[-1]
@@ -810,7 +747,7 @@ class icalTableTestCase(unittest.TestCase):
                     continue
                 if prop_name == 'DTSTAMP':
                     continue
-                datatype = cal.get_datatype(prop_name)
+                datatype = cal.get_record_datatype(prop_name)
                 if getattr(datatype, 'multiple', False) is False:
                     prop = version[prop_name]
                     property = self.property_to_string(prop_name, prop)
@@ -891,30 +828,16 @@ class icalTableTestCase(unittest.TestCase):
         # property ATTENDEE
         name = 'ATTENDEE'
         value = event.get_property(name)
-        param = ['"mailto:DEV-GROUP@host2.com"']
-        value.append(Property('mailto:darwin@itaapy.com',
-                              {'MEMBER': param}))
+        member = '"mailto:DEV-GROUP@host2.com"'
+        value.append(Property('mailto:darwin@itaapy.com', MEMBER=[member]))
         cal.update_record(event.id, **{name: value})
 
         property = event.get_property(name)
         self.assertEqual(str(property[0].value), 'mailto:jdoe@itaapy.com')
-        self.assertEqual(property[1].parameters, {'MEMBER': param})
+        self.assertEqual(property[1].parameters, {'MEMBER': [member]})
         self.assertEqual(property[1], value[1])
 
 
-    def test_icalendar_set_property(self):
-        """ Test setting a new value to an existant icalendar property"""
-        cal = self.cal1
-
-        name, value = 'VERSION', Property('2.1')
-        cal.set_property(name, value)
-        self.assertEqual(cal.get_property(name), value)
-
-        name, value = 'X-test', Property('test property_xxx')
-        cal.set_property(name, [value, ])
-        self.assertEqual(cal.get_property(name), [value, ])
-
-
     def test_component_set_property(self):
         """ Test setting a new value to an existant component property"""
         cal = self.cal1
@@ -924,14 +847,13 @@ class icalTableTestCase(unittest.TestCase):
         cal.update_record(event.id, **{name: value})
         self.assertEqual(event.get_property(name), value)
 
-        name, value = 'ATTENDEE', []
-        param = ['"mailto:DEV-GROUP@host2.com"']
-        value.append(Property(URI.decode('mailto:darwin@itaapy.com'),
-                              {'MEMBER': param}))
-        value.append(Property(URI.decode('mailto:jdoe@itaapy.com')))
-        value.append(Property(URI.decode('mailto:jsmith@itaapy.com')))
-        cal.update_record(event.id, **{name: value})
-        self.assertEqual(event.get_property(name), value)
+        member = '"mailto:DEV-GROUP@host2.com"'
+        value = [
+            Property(URI.decode('mailto:darwin@itaapy.com'), MEMBER=[member]),
+            Property(URI.decode('mailto:jdoe@itaapy.com')),
+            Property(URI.decode('mailto:jsmith@itaapy.com'))]
+        cal.update_record(event.id, ATTENDEE=value)
+        self.assertEqual(event.get_property('ATTENDEE'), value)
 
 
     def test_search_events(self):
@@ -962,8 +884,7 @@ class icalTableTestCase(unittest.TestCase):
         self.assertEqual(len(events), 1)
 
         # Tests with 2 events
-        cal = icalendar()
-        cal.load_state_from_string(content2)
+        cal = iCalendar(string=content2)
         attendee_value = URI.decode('mailto:jdoe@itaapy.com')
 
         events = cal.search_events(ATTENDEE=attendee_value)
