@@ -16,6 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <errno.h>
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -145,17 +146,31 @@ doctype_load_urn (gchar * urn, GString * target)
   gchar buffer[256];
   gint size;
   FILE *file;
+  GString *err_buffer;
+  gchar *error_msg;
 
   /* Search for the good file */
   urn_filename = (gchar *) g_hash_table_lookup (doctype_URN_table, urn);
 
   if (!urn_filename)
-    return ERROR;
+    return DOCTYPE_ERROR ("DTD Error: URN lookup failed");
 
   /* Open the file */
   file = fopen (urn_filename, "r");
   if (!file)
-    return ERROR;
+    {
+      err_buffer = g_string_sized_new (256);
+      g_string_set_size (err_buffer, 0);
+      g_string_append_printf (err_buffer, "Error opening file (%s): %s",
+                              urn_filename, strerror (errno));
+
+      error_msg = g_string_chunk_insert (doctype_global_strings,
+                                         err_buffer->str);
+
+      g_string_free (err_buffer, TRUE);
+
+      return DOCTYPE_ERROR (error_msg);
+    }
 
   /* And read it */
   g_string_set_size (target, 0);
@@ -639,10 +654,11 @@ dtd_read_EntityDecl (DocType * doctype, DTD * dtd)
 {
   gboolean PE = FALSE;
   gchar *name, *value;
+  gboolean error;
 
   /* Read 'ENTITY' */
   if (dtd_read_string (dtd, "TITY"))
-    return ERROR;
+    return DOCTYPE_ERROR ("DTD Error: expected 'TITY' not found");
   dtd_move_cursor (dtd);
 
   dtd_read_S (dtd);
@@ -667,7 +683,7 @@ dtd_read_EntityDecl (DocType * doctype, DTD * dtd)
     case '"':
       /* Read value (in buffer1) */
       if (dtd_read_value (dtd, dtd->buffer1))
-        return ERROR;
+        return DOCTYPE_ERROR ("DTD Error: expected value not found");
 
       dtd_read_S (dtd);
 
@@ -675,15 +691,15 @@ dtd_read_EntityDecl (DocType * doctype, DTD * dtd)
     case 'S':
       /* SYSTEM => We ignore it */
       if (dtd_read_SYSTEM (dtd, dtd->buffer1))
-        return ERROR;
+        return DOCTYPE_ERROR ("DTD Error: expected 'SYSTEM' not found");
 
       if (dtd_ignore_element (dtd))
-        return ERROR;
+        return DOCTYPE_ERROR ("DTD Error: expected element not found");
       return ALL_OK;
     case 'P':
       /* PUBLIC => read it */
       if (dtd_read_PUBLIC (dtd, dtd->buffer1, dtd->buffer2))
-        return ERROR;
+        return DOCTYPE_ERROR ("DTD Error: expected 'PUBLIC' not found");
 
       dtd_read_S (dtd);
 
@@ -692,7 +708,7 @@ dtd_read_EntityDecl (DocType * doctype, DTD * dtd)
       if (!PE && dtd->cursor_char == 'N')
         {
           if (dtd_ignore_element (dtd))
-            return ERROR;
+            return DOCTYPE_ERROR ("DTD Error: expected element not found");
           return ALL_OK;
         }
 
@@ -700,16 +716,17 @@ dtd_read_EntityDecl (DocType * doctype, DTD * dtd)
       doctype_compute_urn (dtd->buffer1->str, dtd->buffer2);
 
       /* And we load the entity */
-      if (doctype_load_urn (dtd->buffer2->str, dtd->buffer1))
-        return ERROR;
+      error = doctype_load_urn (dtd->buffer2->str, dtd->buffer1);
+      if (error)
+        return error;
       break;
     default:
-      return ERROR;
+      return DOCTYPE_ERROR ("DTD Error: unexpected char");
     }
 
   /* Without NDATA, we must finish to read the '>' */
   if (dtd->cursor_char != '>')
-    return ERROR;
+    return DOCTYPE_ERROR ("DTD Error: expected '>' char not found");
   dtd_move_cursor (dtd);
 
   /* Save */
@@ -735,6 +752,8 @@ dtd_read_EntityDecl (DocType * doctype, DTD * dtd)
 gboolean
 dtd_parse (DocType * doctype, DTD * dtd)
 {
+  gboolean error;
+
   for (;;)
     switch (dtd->cursor_char)
       {
@@ -750,7 +769,7 @@ dtd_parse (DocType * doctype, DTD * dtd)
         return ALL_OK;
       case '%':
         if (dtd_read_parameter_entity (dtd))
-          return ERROR;
+          return DOCTYPE_ERROR ("DTD Error: expected parameter entity");
         continue;
       case '<':
         if (dtd_move_cursor (dtd) == '!')
@@ -760,24 +779,25 @@ dtd_parse (DocType * doctype, DTD * dtd)
             case '-':
               /* '<!-' */
               if (dtd_ignore_comment (dtd))
-                return ERROR;
+                return DOCTYPE_ERROR ("DTD Error: ignoring comment failed");
               continue;
             case 'E':
               /* '<!E' */
               if (dtd_move_cursor (dtd) == 'N')
                 {
                   /* '<!EN' */
-                  if (dtd_read_EntityDecl (doctype, dtd))
-                    return ERROR;
+                  error = dtd_read_EntityDecl (doctype, dtd);
+                  if (error)
+                    return error;
                   continue;
                 }
             }
         /* The other cases => ignore it */
         if (dtd_ignore_element (dtd))
-          return ERROR;
+          return DOCTYPE_ERROR ("DTD Error: ignoring element failed");
         continue;
       default:
-        return ERROR;
+        return DOCTYPE_ERROR ("DTD Error: unexpected char");
       }
 }
 
@@ -809,6 +829,7 @@ doctype_read_external_dtd (DocType * doctype, gchar * PubidLiteral,
   GString *err_buffer;
   gchar *error_msg;
   DTD *dtd;
+  gboolean error;
 
   /* Store the values */
   if (PubidLiteral)
@@ -843,17 +864,11 @@ doctype_read_external_dtd (DocType * doctype, gchar * PubidLiteral,
     {
       err_buffer = g_string_sized_new (256);
       g_string_set_size (err_buffer, 0);
-      g_string_append (err_buffer, "'");
       if (PubidLiteral)
-        {
-          g_string_append (err_buffer, PubidLiteral);
-          g_string_append (err_buffer, " (");
-          g_string_append (err_buffer, doctype->buffer->str);
-          g_string_append_c (err_buffer, ')');
-        }
+        g_string_append_printf (err_buffer, "'%s (%s)|", PubidLiteral,
+                                doctype->buffer->str);
       else
-        g_string_append (err_buffer, "None");
-      g_string_append_c (err_buffer, '|');
+        g_string_append (err_buffer, "'None|");
       if (SystemLiteral)
         g_string_append (err_buffer, SystemLiteral);
       else
@@ -874,9 +889,8 @@ doctype_read_external_dtd (DocType * doctype, gchar * PubidLiteral,
     {
       err_buffer = g_string_sized_new (256);
       g_string_set_size (err_buffer, 0);
-      g_string_append (err_buffer, "'");
-      g_string_append (err_buffer, filename);
-      g_string_append (err_buffer, "' no such file");
+      g_string_append_printf (err_buffer, "Error opening file (%s): %s",
+                              filename, strerror (errno));
 
       error_msg = g_string_chunk_insert (doctype_global_strings,
                                          err_buffer->str);
@@ -890,17 +904,10 @@ doctype_read_external_dtd (DocType * doctype, gchar * PubidLiteral,
   dtd = dtd_new (NULL, file, TRUE);
 
   /* And parse it ! */
-  if (dtd_parse (doctype, dtd))
-    {
-      dtd_free (dtd);
-      fclose (file);
-      return ERROR;
-    }
-
-  /* ALL OK */
+  error = dtd_parse (doctype, dtd);
   dtd_free (dtd);
   fclose (file);
-  return ALL_OK;
+  return error;
 }
 
 
@@ -908,6 +915,7 @@ gboolean
 doctype_read_internal_dtd (DocType * doctype, gchar * intSubset)
 {
   DTD *dtd;
+  gboolean error;
 
   /* Store the value */
   doctype->intSubset = g_string_chunk_insert (doctype->strings_storage,
@@ -917,15 +925,9 @@ doctype_read_internal_dtd (DocType * doctype, gchar * intSubset)
   dtd = dtd_new (intSubset, NULL, FALSE);
 
   /* And parse it ! */
-  if (dtd_parse (doctype, dtd))
-    {
-      dtd_free (dtd);
-      return ERROR;
-    }
-
-  /* All OK */
+  error = dtd_parse (doctype, dtd);
   dtd_free (dtd);
-  return ALL_OK;
+  return error;
 }
 
 
